@@ -1,14 +1,14 @@
 # Copyright (c) The Diem Core Contributors
 # SPDX-License-Identifier: Apache-2.0
 
-from dataclasses import dataclass, field, replace, asdict
+from dataclasses import dataclass, field, asdict
 from requests.adapters import HTTPAdapter
 from requests.packages.urllib3.util.retry import Retry
-from typing import List, Optional, Any, Dict, Callable
+from typing import List, Optional, Any, Dict
 from .app import KycSample, Event
 from .app.store import _match
 from ... import offchain, jsonrpc
-import requests, logging, random, string, json, time, os
+import requests, logging, json, os
 
 
 @dataclass
@@ -26,6 +26,7 @@ class RestClient:
     server_url: str
     session: requests.Session = field(default_factory=requests.Session)
     logger: logging.Logger = field(init=False)
+    events_api_is_optional: bool = field(default=False)
 
     def __post_init__(self) -> None:
         self.logger = logging.getLogger(self.name)
@@ -39,22 +40,18 @@ class RestClient:
         balances: Optional[Dict[str, int]] = None,
         kyc_data: Optional[offchain.KycDataObject] = None,
         reject_additional_kyc_data_request: Optional[bool] = None,
+        disable_background_tasks: Optional[bool] = None,
     ) -> "AccountResource":
         kwargs = {
             "balances": balances,
             "kyc_data": asdict(kyc_data) if kyc_data else None,
             "reject_additional_kyc_data_request": reject_additional_kyc_data_request,
+            "disable_background_tasks": disable_background_tasks,
         }
         account = self.create("/accounts", **{k: v for k, v in kwargs.items() if v})
         return AccountResource(client=self, id=account["id"], kyc_data=kyc_data)
 
-    def new_kyc_data(self, name: Optional[str] = None, sample: str = "minimum") -> offchain.KycDataObject:
-        obj = getattr(self.kyc_sample(), sample)
-        if not name:
-            name = "".join(random.choices(string.ascii_uppercase + string.digits, k=6))
-        return replace(obj, legal_entity_name=name)
-
-    def kyc_sample(self) -> KycSample:
+    def get_kyc_sample(self) -> KycSample:
         return offchain.from_dict(self.send("GET", "/kyc_sample").json(), KycSample)
 
     def create(self, path: str, **kwargs: Any) -> Dict[str, Any]:
@@ -78,6 +75,9 @@ class RestClient:
             headers={k: v for k, v in headers.items() if v},
         )
         log_level = logging.DEBUG if resp.status_code < 300 else logging.ERROR
+        if self.events_api_is_optional and path.endswith("/events"):
+            log_level = logging.DEBUG
+
         self.logger.log(log_level, "%s %s: %s - %s", method, path, data, resp.status_code)
         self.logger.log(log_level, "response body: \n%s", try_json(resp.text))
         resp.raise_for_status()
@@ -140,18 +140,6 @@ class AccountResource:
         ret = self.client.send("GET", self._resources("event")).json()
         return [Event(**obj) for obj in ret[start:]]
 
-    def wait_for_balance(self, currency: str, amount: int) -> None:
-        """Wait for account balance of the given currency meets given `amount`
-
-        Raises TimeoutError and AssertionError if waitted too long time (about 12 seconds,
-        120 tries for every 0.1 second).
-        """
-
-        def fn() -> None:
-            assert self.balance(currency) == amount
-
-        self.wait_for(fn)
-
     def find_event(self, event_type: str, start_index: int = 0, **kwargs: Any) -> Optional[Event]:
         """Find a specific event by `type`, `start_index` and `data`
 
@@ -164,38 +152,6 @@ class AccountResource:
             if _match(json.loads(e.data), **kwargs):
                 return e
 
-    def wait_for_event(self, event_type: str, start_index: int = 0, **kwargs: Any) -> None:
-        """Wait for a specific event happened.
-
-        Internally calls to `find_event` to decided whether the event happened.
-        See `find_event` for arguments document.
-        """
-
-        def fn() -> None:
-            event = self.find_event(event_type, start_index=start_index, **kwargs)
-            assert event, "could not find %s event with %s" % (event_type, (start_index, kwargs))
-
-        self.wait_for(fn)
-
-    def wait_for(self, fn: Callable[[], None], max_tries: int = 120, delay: float = 0.1) -> None:
-        """Wait for a fucntion call success
-
-        The given `fn` argument should:
-
-            1. Raise `AssertionError` for the case condition not meet and continue to wait.
-            2. Return `None` for success (meet condition)
-        """
-
-        tries = 0
-        while True:
-            tries += 1
-            try:
-                return fn()
-            except AssertionError as e:
-                if tries >= max_tries:
-                    raise TimeoutError("account(%s) events: %s" % (self.id, self.dump_events())) from e
-                time.sleep(delay)
-
     def log_events(self) -> None:
         """Log account events as INFO
 
