@@ -2,7 +2,7 @@
 # SPDX-License-Identifier: Apache-2.0
 
 from dataclasses import dataclass, field, asdict
-from typing import Dict, Any
+from typing import Dict, Any, List, Tuple
 from .client import RestClient
 from .app import App, falcon_api
 from .. import LocalAccount
@@ -26,9 +26,11 @@ class AppConfig:
     name: str = field(default="mini-wallet")
     disable_events_api: bool = field(default=False)
     account_config: Dict[str, Any] = field(default_factory=lambda: LocalAccount().to_dict())
+    child_account_configs: List[Dict[str, Any]] = field(default_factory=list)
     server_conf: ServerConfig = field(default_factory=ServerConfig)
-    initial_amount: int = field(default=1_000_000_000_000)
+    initial_amount: int = field(default=3_000_000_000_000)
     initial_currency: str = field(default=testnet.TEST_CURRENCY_CODE)
+    child_account_size: int = field(default=2)
 
     @property
     def logger(self) -> logging.Logger:
@@ -38,6 +40,10 @@ class AppConfig:
     def account(self) -> LocalAccount:
         return LocalAccount.from_dict(self.account_config)
 
+    @property
+    def child_accounts(self) -> List[LocalAccount]:
+        return list(map(LocalAccount.from_dict, self.child_account_configs))
+
     @property
     def server_url(self) -> str:
         return self.server_conf.base_url
@@ -47,33 +53,23 @@ class AppConfig:
         return RestClient(server_url=self.server_url, name="%s-client" % self.name).with_retry()
 
     def setup_account(self, client: jsonrpc.Client) -> None:
-        acc = client.get_account(self.account.account_address)
-        if not acc or self.need_funds(acc):
-            self.logger.info("faucet mint %s", self.account.account_address.to_hex())
-            faucet = testnet.Faucet(client)
-            faucet.mint(self.account.auth_key.hex(), self.initial_amount, self.initial_currency)
-        if not acc or self.need_rotate(acc):
-            self.logger.info("rotate dual attestation info for %s", self.account.account_address.to_hex())
-            self.logger.info("set base url to: %s", self.server_url)
-            self.account.rotate_dual_attestation_info(client, self.server_url)
+        self.logger.info("faucet: mint %s", self.account.account_address.to_hex())
+        faucet = testnet.Faucet(client)
+        faucet.mint(self.account.auth_key.hex(), self.initial_amount, self.initial_currency)
 
-    def need_funds(self, account: jsonrpc.Account) -> bool:
-        for balance in account.balances:
-            if balance.currency == self.initial_currency and balance.amount > self.initial_amount / 2:
-                return False
-        return True
+        self.logger.info("rotate dual attestation info for %s", self.account.account_address.to_hex())
+        self.logger.info("set base url to: %s", self.server_url)
+        self.account.rotate_dual_attestation_info(client, self.server_url)
 
-    def need_rotate(self, account: jsonrpc.Account) -> bool:
-        if account.role.base_url != self.server_url:
-            return True
-        if not account.role.compliance_key:
-            return True
-        if bytes.fromhex(account.role.compliance_key) != self.account.compliance_public_key_bytes:
-            return True
-        return False
+        self.logger.info("generate child VASP accounts: %s", self.child_account_size)
+        child_account_initial_amount = int(self.initial_amount / (self.child_account_size + 1))
+        for i in range(self.child_account_size):
+            child = self.account.gen_child_vasp(client, child_account_initial_amount, self.initial_currency)
+            self.logger.info("generate child VASP account(%s): %s", i, child.to_dict())
+            self.child_account_configs.append(child.to_dict())
 
-    def serve(self, client: jsonrpc.Client) -> threading.Thread:
-        api: falcon.API = falcon_api(App(self.account, client, self.name, self.logger), self.disable_events_api)
+    def serve(self, client: jsonrpc.Client, app: App) -> threading.Thread:
+        api: falcon.API = falcon_api(app, self.disable_events_api)
 
         def serve() -> None:
             self.logger.info("serving on %s:%s at %s", self.server_conf.host, self.server_conf.port, self.server_url)
@@ -89,11 +85,12 @@ class AppConfig:
         t.start()
         return t
 
-    def start(self, client: jsonrpc.Client) -> threading.Thread:
+    def start(self, client: jsonrpc.Client) -> Tuple[App, threading.Thread]:
         self.setup_account(client)
-        t = self.serve(client)
+        app = App(self.account, self.child_accounts, client, self.name, self.logger)
+        t = self.serve(client, app)
         utils.wait_for_port(self.server_conf.port, host=self.server_conf.host)
-        return t
+        return (app, t)
 
     def __str__(self) -> str:
         return json.dumps(asdict(self), indent=2)
