@@ -4,17 +4,17 @@
 
 from ... import testnet, jsonrpc, identifier, offchain
 from .. import LocalAccount
-from ..miniwallet import RestClient, AppConfig, AccountResource, ServerConfig, App
-from ..miniwallet.app.event_puller import PENDING_INBOUND_ACCOUNT_ID
+from ..miniwallet import RestClient, AppConfig, AccountResource, ServerConfig, App, Transaction
+from ..miniwallet.app import PENDING_INBOUND_ACCOUNT_ID
 from .envs import (
     target_url,
     is_self_check,
     dmw_stub_server,
     dmw_stub_diem_account_config,
+    dmw_stub_diem_account_hrp,
 )
-from typing import Optional, Tuple, Dict, Any, Generator
+from typing import Optional, Tuple, Dict, Any, Generator, Callable
 from dataclasses import asdict
-from contextlib import contextmanager
 import pytest, json, uuid, requests, time, warnings
 
 
@@ -26,7 +26,7 @@ def target_client(diem_client: jsonrpc.Client) -> RestClient:
         conf.start(diem_client)
         return conf.create_client()
     print("target wallet server url: %s" % target_url())
-    return RestClient(name="target-wallet-client", server_url=target_url()).with_retry()
+    return RestClient(name="target-wallet-client", server_url=target_url(), events_api_is_optional=True).with_retry()
 
 
 @pytest.fixture(scope="package")
@@ -53,6 +53,9 @@ def start_stub_wallet(diem_client: jsonrpc.Client) -> Tuple[AppConfig, App]:
     if account_conf:
         print("loads stub account config: %s" % account_conf)
         conf.account_config = json.loads(account_conf)
+    hrp = dmw_stub_diem_account_hrp()
+    if hrp:
+        conf.account_config["hrp"] = hrp
     print("Start stub app with config %s" % conf)
     app, _ = conf.start(diem_client)
     return (conf, app)
@@ -94,20 +97,20 @@ def travel_rule_threshold(diem_client: jsonrpc.Client) -> int:
 
 
 @pytest.fixture
-def pending_income_account(stub_client: RestClient) -> AccountResource:
+def stub_wallet_pending_income_account(stub_client: RestClient) -> AccountResource:
+    """MiniWallet stub saves the payment without account information (subaddress / reference id)
+    into a pending income account before processing it.
+    """
+
     return AccountResource(id=PENDING_INBOUND_ACCOUNT_ID, client=stub_client)
 
 
-@contextmanager
-def disable_background_tasks(app: App) -> Generator[None, None, None]:
-    app.bg_worker = "disable"
-    # wait for status changed from disable to disabled
-    while app.bg_worker == "disable":
-        time.sleep(0.01)
-    try:
-        yield
-    finally:
-        app.bg_worker = "running"
+@pytest.fixture(autouse=True)
+def log_stub_wallet_pending_income_account(
+    stub_wallet_pending_income_account: AccountResource,
+) -> Generator[None, None, None]:
+    yield
+    stub_wallet_pending_income_account.log_events()
 
 
 def send_request_json(
@@ -199,3 +202,52 @@ def set_field(dic: Dict[str, Any], field: str, value: Any) -> None:  # pyre-igno
         dic = dic[f]
 
     dic[path[len(path) - 1]] = value
+
+
+def wait_for(fn: Callable[[], None], max_tries: int = 60, delay: float = 0.1) -> None:
+    """Wait for a function call success
+
+    The given `fn` argument should:
+
+        1. Raise `AssertionError` for the case condition not meet and continue to wait.
+        2. Return `None` for success (meet condition)
+    """
+
+    tries = 0
+    while True:
+        tries += 1
+        try:
+            return fn()
+        except AssertionError as e:
+            if tries >= max_tries:
+                raise e
+            time.sleep(delay)
+
+
+def wait_for_balance(account: AccountResource, currency: str, amount: int) -> None:
+    """Wait for account balance of the given currency meets given `amount`"""
+
+    def match_balance() -> None:
+        assert account.balance(currency) == amount
+
+    wait_for(match_balance)
+
+
+def wait_for_event(account: AccountResource, event_type: str, start_index: int = 0, **kwargs: Any) -> None:
+    """Wait for a specific event happened.
+
+    Internally calls to `AccountResource#find_event` to decided whether the event happened.
+    See `AccountResource#find_event` for arguments document.
+    """
+
+    def match_event() -> None:
+        event = account.find_event(event_type, start_index=start_index, **kwargs)
+        assert event, "could not find %s event with %s" % (event_type, (start_index, kwargs))
+
+    wait_for(match_event)
+
+
+def wait_for_payment_transaction_complete(account: AccountResource, payment_id: str) -> None:
+    # MiniWallet stub generates `updated_transaction` event when transaction is completed on-chain
+    # Payment id is same with Transaction id.
+    wait_for_event(account, "updated_transaction", status=Transaction.Status.completed, id=payment_id)
