@@ -28,8 +28,8 @@ from . import diem_types, jsonrpc, utils, chain_ids, bcs, identifier
 from .testing import LocalAccount
 
 
-JSON_RPC_URL: str = "http://testnet.diem.com/v1"
-FAUCET_URL: str = "http://testnet.diem.com/mint"
+JSON_RPC_URL: str = "https://testnet.diem.com/v1"
+FAUCET_URL: str = "https://testnet.diem.com/mint"
 CHAIN_ID: diem_types.ChainId = chain_ids.TESTNET
 
 DESIGNATED_DEALER_ADDRESS: diem_types.AccountAddress = utils.account_address("000000000000000000000000000000dd")
@@ -94,7 +94,7 @@ class Faucet:
 
     def _mint_without_retry(self, authkey: str, amount: int, currency_code: str, dd_account: bool = False) -> None:
         response = self._session.post(
-            FAUCET_URL,
+            self._url,
             params={
                 "amount": amount,
                 "auth_key": authkey,
